@@ -258,7 +258,7 @@ class ThetaClient:
 
     def get_stk_at_time(
             self,
-            req: OptionReqType,
+            req: StockReqType,
             root: str,
             date_range: DateRange,
             ms_of_day: int = 0,
@@ -280,7 +280,7 @@ class ThetaClient:
         end_fmt = _format_date(date_range.end)
 
         # send request
-        hist_msg = f"MSG_CODE={MessageType.AT_TIME.value}&START_DATE={start_fmt}&END_DATE={end_fmt}&root={root}&sec={SecType.OPTION.value}&req={req.value}&IVL={ms_of_day}\n"
+        hist_msg = f"MSG_CODE={MessageType.AT_TIME.value}&START_DATE={start_fmt}&END_DATE={end_fmt}&root={root}&sec={SecType.STOCK.value}&req={req.value}&IVL={ms_of_day}\n"
         self._server.sendall(hist_msg.encode("utf-8"))
 
         # parse response header
@@ -336,7 +336,7 @@ class ThetaClient:
 
     def get_dates_stk(self, root: str, req: StockReqType) -> pd.Series:
         """
-        Get all option expirations.
+        Get all dates of data available for a given stock contract and request type.
 
         :param req:            The request type.
         :param root:           The root symbol.
@@ -358,11 +358,12 @@ class ThetaClient:
             strike: float,
             right: OptionRight) -> pd.Series:
         """
-        Get all option expirations.
+        Get all dates of data available for a given option contract and request type.
+
         :param req:            The request type.
         :param root:           The root symbol.
         :param exp:            The expiration date. Must be after the start of `date_range`.
-        :param strike:         The strike price in USD, rounded to 1/10th of a cent.
+        :param strike:         The strike price in USD.
         :param right:          The right of an option.
         :param root:           The root symbol.
         :return:               All dates that Theta Data provides data for given a request.
@@ -444,7 +445,7 @@ class ThetaClient:
         right: OptionRight,
     ) -> pd.DataFrame:
         """
-        Get the most recent option data.
+        Get the most recent option tick.
 
         :param req:            The request type.
         :param root:           The root symbol.
@@ -469,7 +470,33 @@ class ThetaClient:
         body: DataFrame = TickBody.parse(
             hist_msg, header, self._recv(header.size)
         )
+        return body
 
+    def get_last_stock(
+        self,
+        req: StockReqType,
+        root: str,
+    ) -> pd.DataFrame:
+        """
+        Get the most recent stock tick.
+
+        :param req:            The request type.
+        :param root:           The root symbol.
+
+        :return:               The requested data as a pandas DataFrame.
+        :raises ResponseError: If the request failed.
+        """
+        assert self._server is not None, _NOT_CONNECTED_MSG
+
+        # send request
+        hist_msg = f"MSG_CODE={MessageType.LAST.value}&root={root}&sec={SecType.STOCK.value}&req={req.value}\n"
+        self._server.sendall(hist_msg.encode("utf-8"))
+
+        # parse response
+        header: Header = Header.parse(hist_msg, self._server.recv(20))
+        body: DataFrame = TickBody.parse(
+            hist_msg, header, self._recv(header.size)
+        )
         return body
 
     def get_req(
